@@ -1,12 +1,9 @@
 # -*- coding: utf-8 -*-
 
-import base64
 import copy
 import json
 import os
-import platform
 import sys
-import time
 
 import django
 import eanoui
@@ -14,7 +11,7 @@ from django import template
 from django.contrib.admin.templatetags.admin_urls import add_preserved_filters
 from django.core.serializers.json import DjangoJSONEncoder
 from django.db import models
-from django.urls import is_valid_path, reverse
+from django.urls import reverse
 from django.utils.encoding import force_text
 from django.utils.functional import Promise
 from django.utils.html import format_html
